@@ -1,10 +1,13 @@
+import logging
+
+import cv2
+
 from docstruct.visual_detection.bordered_table_extraction import BorderedTableExtractor
 from docstruct.visual_detection.vis_line_detection import VisLineDetector, VisLineMerger
-from .textract_parser import TextractParser
+
 from .hocr_parser import HocrParser
-from .text_block import Word, Page
-import cv2
-import logging
+from .text_block import Page, Word
+from .textract_parser import TextractParser
 
 
 class PageCreator:
@@ -61,5 +64,5 @@ class PageCreator:
                 table.group_words_into_cells(words)
             page.set_tables(tables)
         except Exception as e:
-            logging.warning(e)
+            logging.error(e)
         return page
