@@ -95,7 +95,7 @@ class ParagraphExtractor:
             for j in range(i + 1, self.num_nodes):
                 if (
                     self.are_adjacent(nodes[i], nodes[j])
-                    and not self.is_indented(nodes[i], nodes[j])
+                    # and not self.is_indented(nodes[i], nodes[j])
                     and not self.is_bullet_number(nodes[j])
                 ):
                     nodes[i].add_neighbor(nodes[j])
