@@ -1,4 +1,5 @@
 import collections
+import math
 
 from .bounding_box import BoundingBox
 from .constants import LINE, PAGE, WORD
@@ -135,7 +136,7 @@ class TextractParser:
             lines_segments=lines_segments,
         )
         paragraphs = paragraphs_extractor.extract_paragraphs()
-        paragraphs = sort_paragraphs(paragraphs)
+        paragraphs = sort_paragraphs(paragraphs=paragraphs, height_offset=height_offset)
         return paragraphs
 
     def extract_page(self, paragraphs: list[Paragraph]) -> Page:
@@ -182,6 +183,11 @@ class TextractParser:
         running_sum = 0
         for space in space_distribution:
             running_sum += space
-            if running_sum / total >= 0.15:
-                return space
+            if running_sum / total >= 0.05:
+                return round_up(space, 3)
         return 0
+
+
+def round_up(n: float, decimals: float = 0) -> float:
+    multiplier = 10**decimals
+    return math.ceil(n * multiplier) / multiplier
